Where to start
=========================================

.. hint::
   This page is under construction. Consider helping us developing it by `contributing <https://neurokit2.readthedocs.io/en/latest/contributing/index.html>`_.


Here are a few examples that a good for starting with NeuroKit.

- `Event-related Analysis <https://neurokit2.readthedocs.io/en/latest/examples/eventrelated.html>`_